def findSlope(x, y):
  xToString = str(x)
  yToString = str(y)
  print("Slope is " + xToString + "/ " + yToString)

def slopeIntercept(x, y):
  print("y = " + str(x) + "x + " + str(y))